'use strict';
var express = require('express'),
	router = express.Router(),
	returnCode = require('../../utils/returnCode'),
	_ = require('lodash');

var mongoose = require('mongoose');
var moment = require('moment');
var forumUserService=require('../../service/forumUserService');
var forumThreadService=require('../../service/forumThreadService');
var httpService=require('../../service/httpService');
var forumLimitActionRefService=require('../../service/forumLimitActionRefService');
var forumLimitActionConfigService=require('../../service/forumLimitActionConfigService');

var async=require('async');

var user=require('../../utils/user');

module.exports = function(app) {
	app.use('/admin/forum', router);
};

//格式化日期 (格式：年-月-日)
function date_format(date) {
    return moment(date).format('YYYY-MM-DD');
}

//判断时间是否在指定范围
function compareTime(now, begin_time, end_time) {
    now = date_format(now);
    begin_time = date_format(begin_time);
    end_time = date_format(end_time);
    if (moment(now).isSame(begin_time) || moment(now).isSame(end_time)) { //如果等于开始时间或者结束时间
        return true;
    } else {
        return moment(now).isBetween(begin_time, end_time);
    }
}


//验证用户身份
router.post('/user/identifyUser',function(req,res,next){
	var entity=req.body;
	if(!req.session.mobileForumUser){
			forumUserService.getUserByUid(entity.uid,function(err,doc){
				if(err){
					console.log(err);
					res.json('error');
				}else{
					if(doc){
						req.session.mobileForumUser={
							userId:doc._id,
							openId:doc.uid
						};
						// checkLimitAction(req, res);
						res.json({result:'success',userId:doc._id});
					}else{
						forumUserService.createUser(entity,function(err,doc){
							if(err){
								console.log(err);
								res.json('error');
							}else{
								req.session.mobileForumUser={
									userId:doc._id,
									openId:doc.uid
								};
								// checkLimitAction(req, res);
								res.json({result:'success',userId:doc._id});
							}
						});
					}
				}
			});
	}else{
		res.json({result:'success',userId:req.session.mobileForumUser.userId});
	}
});
//微信分享带来用户
router.get('/user/from/share', function(req, res, next) {
	var userId = req.session.mobileForumUser.userId;

    var mid = req.query.mid,
        action = req.query.action,
        ent_code = req.query.ent_code;

    forumLimitActionRefService.checkLimitActionProhibitionAddIntegral(userId, function(err, flag){
    	if(err){
    		console.error(err);
            res.json(returnCode.PROHIBITION_OF_SPEECH);
    	}else{
    		if(flag){
                res.json(returnCode.PROHIBITION_OF_SPEECH);
    		}else{
    			httpService.sendRequest(ent_code,mid,action);
    			res.status(200).end();
    		}
    	}
    });

    // httpService.sendRequest(ent_code,mid,action);
    // res.status(200).end();
});

//检查用户权限
router.post('/user/checkLimitAction', function(req, res, next) {
	var entity=req.body;
	var userId = entity.mid;
	if(userId){
		forumLimitActionConfigService.getAllLimitActionConfig(function(err,configs){
			if(err){
				console.error(err);
				res.json(returnCode.BUSY);
			}else{
				var array = [];
				forumLimitActionRefService.getLimitActionRefByMid(userId,function(err,forumLimitActionRef){
					if (err) {
						console.error(err);
						var returnObject = {
		                	errcode:'success',
		                	configs:configs,
		                	data:array
		                }
		                res.json(returnObject);
					} else {
						// 获取到用户行为限制记录
						if(forumLimitActionRef){
							var limit_actions = forumLimitActionRef.limit_actions;
			                for (var i = 0; i < limit_actions.length; i += 1) {
			                    var limit_action = limit_actions[i];
			                    var flag = compareTime(new Date(), limit_action.begin_time, limit_action.end_time);
			                    //把flag和limit_action_type 放进session
			                    var obj = {
			                    	result : flag,
			                    	code : limit_action.limit_action_type
			                    }
			                    array.push(obj);
			                }
			                var returnObject = {
			                	errcode:'success',
			                	configs:configs,
			                	data:array
			                }
			                res.json(returnObject);
						}else{
							var returnObject = {
			                	errcode:'success',
			                	configs:configs,
			                	data:[]
			                }
							res.json(returnObject);
						}
					}
				});
			}
		});
	}else{
		var returnObject = {
        	errcode:'success',
        	configs:configs,
        	data:[]
        }
		res.json(returnObject);
	}
});
